@@ -32,7 +32,7 @@ from .structures import (
 
 
 def _get_raw_country_data() -> List[Dict]:
-    with open("countries.csv", "r") as fp:
+    with open("countries.csv", "r+") as fp:
         raw_csv_data = fp.read()
 
     return [
